<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\Category;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class CategoryController extends Controller
{
    /**
     * index
     *
     * @return void
     */
    public function index()
    {
        try {
            $categories = Category::with(['products' => function($query) {
                $query->select('id', 'category_id', 'name', 'price', 'image');
            }])->get();

            return response()->json([
                'status' => true,
                'categories' => $categories
            ]);
        } catch (\Exception $e) {
            \Log::error('Kategori listesi getirme hatası: ' . $e->getMessage());
            return response()->json([
                'status' => false,
                'message' => 'Kategoriler getirilemedi',
                'error' => $e->getMessage()
            ], 500);
        }
    }


    /**
     * show
     *
     * @param  mixed $id
     * @return void
     */
    public function show($id)
    {
        try {
            $category = Category::find($id);
            return response()->json(['status' => true, 'message' => 'Category fetched successfully', 'category' => $category], 200);
        } catch (\Exception $e) {
            return response()->json(['status' => false, 'message' => 'Category fetching failed', 'errors' => $e->getMessage()], 500);
        }
    }

    /**
     * store
     *
     * @param  mixed $request
     * @return void
     */
    public function store(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'name' => 'required|string|max:255',
                'total_products' => 'nullable|integer',
            ]);

            if ($validator->fails()) {
                return response()->json(['status' => false, 'message' => 'Validation failed', 'errors' => $validator->errors()], 422);
            }
            $category = Category::create($request->all());
            return response()->json(['status' => true, 'message' => 'Category created successfully', 'category' => $category], 200);
        } catch (\Exception $e) {
            return response()->json(['status' => false, 'message' => 'Category creation failed', 'errors' => $e->getMessage()], 500);
        }
    }

    /**
     * update
     *
     * @param  mixed $request
     * @param  mixed $id
     * @return void
     */
    public function update(Request $request, $id)
    {
        try {
            $validator = Validator::make($request->all(), [
                'name' => 'required|string|max:255',
                'total_products' => 'nullable|integer',
            ]);

            if ($validator->fails()) {
                return response()->json(['status' => false, 'message' => 'Validation failed', 'errors' => $validator->errors()], 422);
            }

            $category = Category::find($id);
            $category->update($request->all());
            return response()->json(['status' => true, 'message' => 'Category updated successfully', 'category' => $category], 200);
        } catch (\Exception $e) {
            return response()->json(['status' => false, 'message' => 'Category update failed', 'errors' => $e->getMessage()], 500);
        }
    }

    /**
     * destroy
     *
     * @param  mixed $id
     * @return void
     */
    public function destroy($id)
    {
        try {
            $category = Category::find($id);
            $category->delete();
            return response()->json(['status' => true, 'message' => 'Category deleted successfully'], 200);
        } catch (\Exception $e) {
            return response()->json(['status' => false, 'message' => 'Category deletion failed', 'errors' => $e->getMessage()], 500);
        }
    }

}
