<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\KitchenOrder;
use Illuminate\Http\Request;

class KitchenController extends Controller
{
    /**
     * Mutfak siparişlerini listele
     */
    public function index(Request $request)
    {
        try {
            $query = KitchenOrder::with(['product', 'table', 'order'])
                ->whereHas('product')
                ->whereHas('table')
                ->where('status', 'pending')
                ->orderBy('created_at', 'asc')
                ->get();

            // Daha okunabilir bir format için dönüştürme yapalım
            $formattedOrders = $query->map(function ($order) {
                return [
                    'id' => $order->id,
                    'table_name' => $order->table->name,
                    'product_name' => $order->product->name,
                    'product_image' => $order->product->image,
                    'quantity' => $order->quantity,
                    'status' => $order->status,
                    'created_at' => $order->created_at->format('d-m-Y H:i'),
                    'order_id' => $order->order_id,
                    'table_id' => $order->table_id,
                    'product_id' => $order->product_id,
                    'product_description' => $order->product->description
                ];
            });

            return response()->json([
                'status' => true,
                'message' => 'Bekleyen mutfak siparişleri getirildi',
                'kitchen_orders' => $formattedOrders
            ], 200);

        } catch (\Exception $e) {
            return response()->json([
                'status' => false,
                'message' => 'Mutfak siparişleri getirilemedi',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    /**
     * Mutfak siparişinin durumunu güncelle
     */
    public function updateStatus(Request $request, $id)
    {
        try {
            $kitchenOrder = KitchenOrder::findOrFail($id);

            $kitchenOrder->update([
                'status' => $request->status
            ]);

            return response()->json([
                'status' => true,
                'message' => 'Sipariş durumu güncellendi',
                'kitchen_order' => $kitchenOrder->fresh()
            ], 200);

        } catch (\Exception $e) {
            return response()->json([
                'status' => false,
                'message' => 'Sipariş durumu güncellenemedi',
                'error' => $e->getMessage()
            ], 500);
        }
    }
}
