<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\QrOrder;
use App\Models\QrOrderItem;
use App\Models\Product;
use App\Models\Table;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;

class QrMenuController extends Controller
{
    public function addOrder(Request $request, $tableId)
    {
        DB::beginTransaction();
        try {
            $validator = Validator::make($request->all(), [
                'products' => 'required|array',
                'products.*.product_id' => 'required|exists:products,id',
                'products.*.quantity' => 'required|integer|min:1'
            ]);

            if ($validator->fails()) {
                return response()->json([
                    'status' => false,
                    'message' => 'Doğrulama hatası',
                    'errors' => $validator->errors()
                ], 422);
            }

            $table = Table::findOrFail($tableId);
            $totalPrice = 0;

            // QR Sipariş oluştur
            $qrOrder = QrOrder::create([
                'table_id' => $tableId,
                'status' => 'pending'
            ]);

            foreach ($request->products as $item) {
                $product = Product::findOrFail($item['product_id']);
                $itemPrice = $product->price * $item['quantity'];

                // QR Sipariş ürünlerini ekle
                QrOrderItem::create([
                    'qr_order_id' => $qrOrder->id,
                    'product_id' => $item['product_id'],
                    'quantity' => $item['quantity'],
                    'price' => $product->price
                ]);

                $totalPrice += $itemPrice;
            }

            // Toplam fiyatı güncelle
            $qrOrder->update([
                'total_price' => $totalPrice
            ]);

            DB::commit();

            return response()->json([
                'status' => true,
                'message' => 'Sipariş başarıyla alındı',
                'qr_order' => $qrOrder->load(['items.product'])
            ], 200);

        } catch (\Exception $e) {
            DB::rollBack();
            return response()->json([
                'status' => false,
                'message' => 'Sipariş oluşturulamadı',
                'error' => $e->getMessage()
            ], 500);
        }
    }
}
