<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Models\QrOrder;
use App\Models\Order;
use App\Models\OrderItem;
use App\Models\KitchenOrder;
use App\Models\Table;
use App\Models\TableStatus;
use App\Enums\TableStatus as TableStatusEnum;
use Illuminate\Http\Request;
use DB;

class QrOrderController extends Controller
{
    public function getPendingOrders()
    {
        try {
            $orders = QrOrder::with(['items.product', 'table'])
                ->where('status', 'pending')
                ->get();

            return response()->json([
                'status' => true,
                'orders' => $orders
            ]);
        } catch (\Exception $e) {
            return response()->json([
                'status' => false,
                'message' => 'Siparişler getirilemedi',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    public function approveOrder($id)
    {
        DB::beginTransaction();
        try {
            $qrOrder = QrOrder::with('items.product')->findOrFail($id);
            $table = Table::findOrFail($qrOrder->table_id);

            // Aktif sipariş var mı kontrol et
            $order = Order::where('table_id', $qrOrder->table_id)
                ->where('is_paid', false)
                ->where('archived', false)
                ->first();

            // Yoksa yeni sipariş oluştur
            if (!$order) {
                $order = Order::create([
                    'table_id' => $qrOrder->table_id,
                    'total_price' => 0,
                    'status' => 'active',
                    'is_paid' => false,
                    'archived' => false
                ]);
            }

            // Siparişleri ekle
            foreach ($qrOrder->items as $item) {
                $orderItem = OrderItem::create([
                    'order_id' => $order->id,
                    'product_id' => $item->product_id,
                    'quantity' => $item->quantity,
                    'price' => $item->price
                ]);

                // Mutfak siparişi oluştur
                if ($item->product->kitchen_print) {
                    KitchenOrder::create([
                        'order_id' => $order->id,
                        'order_item_id' => $orderItem->id,
                        'product_id' => $item->product_id,
                        'table_id' => $qrOrder->table_id,
                        'quantity' => $item->quantity,
                        'status' => 'pending'
                    ]);
                }
            }

            // Toplam fiyatı güncelle
            $order->total_price = $order->total_price + $qrOrder->total_price;
            $order->save();

            // Masa durumunu güncelle
            $table->update([
                'status' => TableStatusEnum::ACTIVE,
                'date' => now(),
                'total_price' => $order->total_price,
                'product_count' => OrderItem::where('order_id', $order->id)->sum('quantity')
            ]);

            // QR siparişi onayla
            $qrOrder->update(['status' => 'approved']);

            DB::commit();
            return response()->json([
                'status' => true,
                'message' => 'Sipariş onaylandı',
                'order' => $order->load(['orderItems.product', 'kitchenOrders']),
                'table' => $table
            ]);
        } catch (\Exception $e) {
            DB::rollBack();
            return response()->json([
                'status' => false,
                'message' => 'Sipariş onaylanamadı',
                'error' => $e->getMessage()
            ], 500);
        }
    }

    public function rejectOrder($id)
    {
        try {
            $qrOrder = QrOrder::findOrFail($id);
            $qrOrder->update(['status' => 'rejected']);

            return response()->json([
                'status' => true,
                'message' => 'Sipariş reddedildi'
            ]);
        } catch (\Exception $e) {
            return response()->json([
                'status' => false,
                'message' => 'Sipariş reddedilemedi',
                'error' => $e->getMessage()
            ], 500);
        }
    }
}
