@extends('menu.layout')

@section('content')
<div class="space-y-8 animate-fade">
    <!-- Masa Seçimi -->
    <div class="glass-effect rounded-2xl p-6 border border-white/5">
        <h2 class="text-xl font-bold text-white mb-4">Masa Seçin</h2>
        <select id="tableSelect" class="w-full bg-white/5 border border-white/10 rounded-xl px-4 py-3 text-white focus:outline-none focus:border-rose-500">
            <option value="">Masa Seçin</option>
        </select>
    </div>

    <!-- Tab Sistemi -->
    <div class="glass-effect rounded-2xl border border-white/5 overflow-hidden">
        <!-- Kategoriler (Tab Headers) -->
        <div class="overflow-x-auto whitespace-nowrap p-4 border-b border-white/5">
            <div id="categoryTabs" class="inline-flex space-x-2">
                <!-- Kategoriler JS ile doldurulacak -->
            </div>
        </div>

        <!-- Ürünler (Tab Content) -->
        <div class="p-6">
            <div id="productList" class="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-4">
                <!-- Ürünler JS ile doldurulacak -->
            </div>
        </div>
    </div>

    <!-- Sipariş Özeti -->
    <div class="glass-effect rounded-2xl p-6 border border-white/5">
        <h2 class="text-xl font-bold text-white mb-4">Sipariş Özeti</h2>
        <div id="orderItems" class="space-y-2 mb-4">
            <!-- Sipariş öğeleri JS ile doldurulacak -->
        </div>
        <div class="border-t border-white/10 pt-4 mt-4">
            <div class="flex justify-between items-center">
                <span class="text-white font-semibold">Toplam Tutar:</span>
                <span id="totalAmount" class="text-white font-bold">0.00 ₺</span>
            </div>
        </div>
        <button id="submitOrder" class="w-full mt-4 px-6 py-3 bg-gradient-to-r from-rose-500 to-orange-500 text-white rounded-xl font-semibold disabled:opacity-50 disabled:cursor-not-allowed">
            Siparişi Gönder
        </button>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    let selectedTable = null;
    let selectedCategory = null;
    let orderItems = {};
    let products = [];

    // Masaları yükle
    loadTables();
    // Kategorileri yükle
    loadCategories();

    // Masa seçimi değiştiğinde
    document.getElementById('tableSelect').addEventListener('change', function(e) {
        selectedTable = e.target.value;
        updateSubmitButton();
    });

    // Kategorileri yükle
    function loadCategories() {
        fetch('/api/v1/menu/categories')
            .then(response => response.json())
            .then(data => {
                if (data.status && data.categories) {
                    const categoryTabs = document.getElementById('categoryTabs');
                    categoryTabs.innerHTML = data.categories.map((category, index) => `
                        <button onclick="loadProducts(${category.id})"
                                class="category-tab px-6 py-2 rounded-xl text-white/70 hover:text-white transition-colors ${index === 0 ? 'active bg-white/10 text-white' : ''}"
                                data-category-id="${category.id}">
                            ${category.name}
                        </button>
                    `).join('');

                    // İlk kategoriyi otomatik seç
                    if (data.categories.length > 0) {
                        loadProducts(data.categories[0].id);
                    }
                }
            })
            .catch(error => console.error('Kategoriler yüklenirken hata:', error));
    }

    // Ürünleri yükle
    window.loadProducts = function(categoryId) {
        selectedCategory = categoryId;

        // Aktif tab'ı güncelle
        document.querySelectorAll('.category-tab').forEach(tab => {
            if (tab.dataset.categoryId == categoryId) {
                tab.classList.add('active', 'bg-white/10', 'text-white');
            } else {
                tab.classList.remove('active', 'bg-white/10', 'text-white');
            }
        });

        fetch(`/api/v1/menu/products?category_id=${categoryId}`)
            .then(response => response.json())
            .then(data => {
                if (data.status && data.products) {
                    products = data.products;
                    const productList = document.getElementById('productList');
                    productList.innerHTML = products
                        .filter(product => product.category_id == categoryId)
                        .map(product => `
                            <div class="product-card glass-effect rounded-xl border border-white/5 overflow-hidden">
                                <img src="/storage/${product.image}" alt="${product.name}"
                                     class="w-full h-48 object-cover">
                                <div class="p-4">
                                    <h3 class="font-semibold text-white">${product.name}</h3>
                                    <p class="text-white/70 text-sm mb-3">${product.description}</p>
                                    <div class="flex items-center justify-between">
                                        <span class="text-white font-bold">${product.price} ₺</span>
                                        <div class="flex items-center space-x-2">
                                            <button onclick="updateQuantity(${product.id}, -1)"
                                                    class="w-8 h-8 rounded-lg bg-white/5 hover:bg-white/10 text-white flex items-center justify-center">
                                                -
                                            </button>
                                            <span class="text-white min-w-[20px] text-center">
                                                ${orderItems[product.id]?.quantity || 0}
                                            </span>
                                            <button onclick="updateQuantity(${product.id}, 1)"
                                                    class="w-8 h-8 rounded-lg bg-white/5 hover:bg-white/10 text-white flex items-center justify-center">
                                                +
                                            </button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        `).join('');
                }
            })
            .catch(error => console.error('Ürünler yüklenirken hata:', error));
    }

    // Masaları yükle
    function loadTables() {
        fetch('/api/v1/menu/tables/active')
            .then(response => {
                if (!response.ok) {
                    throw new Error('Network response was not ok');
                }
                return response.json();
            })
            .then(data => {
                console.log('Gelen masa verisi:', data); // Hata ayıklama için
                if (data.status && data.tables) {
                    const tableSelect = document.getElementById('tableSelect');
                    if (!tableSelect) {
                        console.error('tableSelect elementi bulunamadı');
                        return;
                    }

                    tableSelect.innerHTML = '<option value="">Masa Seçin</option>';

                    data.tables.forEach(table => {
                        tableSelect.innerHTML += `
                            <option value="${table.id}">${table.name}</option>
                        `;
                    });
                } else {
                    console.error('Masalar yüklenemedi:', data);
                    alert('Masalar yüklenemedi: ' + (data.message || 'Bilinmeyen hata'));
                }
            })
            .catch(error => {
                console.error('Masalar yüklenirken hata:', error);
                alert('Masalar yüklenirken bir hata oluştu!');
            });
    }

    // Ürün miktarını güncelle
    window.updateQuantity = function(productId, change) {
        if (!orderItems[productId]) {
            orderItems[productId] = { quantity: 0 };
        }

        const newQuantity = orderItems[productId].quantity + change;
        if (newQuantity >= 0) {
            orderItems[productId].quantity = newQuantity;
            updateOrderSummary();

            // Ürün kartındaki miktarı güncelle
            const quantityElement = document.querySelector(`[onclick*="updateQuantity(${productId},"]`)
                .parentElement.querySelector('span');
            if (quantityElement) {
                quantityElement.textContent = newQuantity;
            }
        }
    }

    // Sipariş özetini güncelle
    function updateOrderSummary() {
        const orderItemsContainer = document.getElementById('orderItems');
        let total = 0;

        const items = Object.entries(orderItems)
            .filter(([_, item]) => item.quantity > 0)
            .map(([productId, item]) => {
                const product = products.find(p => p.id == productId);
                if (product) {
                    const subtotal = product.price * item.quantity;
                    total += subtotal;
                    return `
                        <div class="flex justify-between items-center text-white/70">
                            <div>
                                <span class="font-semibold text-white">${product.name}</span>
                                <span class="text-sm"> x ${item.quantity}</span>
                            </div>
                            <span>${subtotal.toFixed(2)} ₺</span>
                        </div>
                    `;
                }
                return '';
            });

        orderItemsContainer.innerHTML = items.join('');
        document.getElementById('totalAmount').textContent = total.toFixed(2) + ' ₺';
        updateSubmitButton();
    }

    // Gönder butonunu güncelle
    function updateSubmitButton() {
        const submitButton = document.getElementById('submitOrder');
        const hasItems = Object.values(orderItems).some(item => item.quantity > 0);
        submitButton.disabled = !selectedTable || !hasItems;
    }

    // Siparişi gönder
    document.getElementById('submitOrder').addEventListener('click', function() {
        if (!selectedTable) {
            alert('Lütfen bir masa seçin');
            return;
        }

        const products = Object.entries(orderItems)
            .filter(([_, item]) => item.quantity > 0)
            .map(([productId, item]) => ({
                product_id: parseInt(productId),
                quantity: item.quantity
            }));

        fetch(`/api/v1/menu/tables/${selectedTable}/add-order`, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'Accept': 'application/json',
            },
            body: JSON.stringify({ products })
        })
        .then(response => response.json())
        .then(data => {
            if (data.status) {
                alert('Sipariş başarıyla oluşturuldu!');
                window.location.href = '/';
            } else {
                alert('Sipariş oluşturulurken bir hata oluştu!');
            }
        })
        .catch(error => {
            alert('Bir hata oluştu!');
            console.error('Error:', error);
        });
    });
});
</script>

<style>
.glass-effect {
    background: rgba(255, 255, 255, 0.03);
    backdrop-filter: blur(12px);
}
.product-card {
    transition: transform 0.2s;
}
.product-card:hover {
    transform: translateY(-2px);
}
.category-tab.active {
    position: relative;
}
.category-tab.active::after {
    content: '';
    position: absolute;
    bottom: -4px;
    left: 50%;
    transform: translateX(-50%);
    width: 20px;
    height: 2px;
    background: linear-gradient(to right, #f43f5e, #f97316);
    border-radius: 1px;
}
</style>
@endsection
