<?php

use App\Http\Controllers\Api\AuthController;
use App\Http\Controllers\Api\CategoryController;
use App\Http\Controllers\Api\ProductController;
use App\Http\Controllers\Api\TableController;
use App\Http\Controllers\Api\TableAddOrderController;
use App\Http\Controllers\Api\ReportsController;
use App\Http\Controllers\WaiterCallController;
use App\Http\Controllers\Api\KitchenController;
use App\Http\Controllers\Api\PaymentController;
use App\Http\Controllers\Api\QrOrderController;
use App\Http\Controllers\Api\QrMenuController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Middleware\AdminMiddleware;
use App\Http\Middleware\WaiterMiddleware;


Route::group(['prefix' => 'v1'], function () {
    Route::post('/login', [AuthController::class, 'login']);
    Route::post('/register', [AuthController::class, 'register']);

    Route::get('/tables/active', [TableController::class, 'getActiveTables']);
    Route::post('/waiter-call', [WaiterCallController::class, 'store']);
    Route::get('/waiter-calls/pending', [WaiterCallController::class, 'getPendingCalls']);
    Route::post('/waiter-calls/{id}/complete', [WaiterCallController::class, 'complete']);


    Route::group(['middleware' => 'auth:sanctum', 'prefix' => 'tables'], function () {
        Route::get('/index', [TableController::class, 'index']);
        Route::get('/show/{id}', [TableController::class, 'show']);
        Route::post('/store', [TableController::class, 'store']);
        Route::put('/update/{id}', [TableController::class, 'update']);
        Route::delete('/destroy/{id}', [TableController::class, 'destroy']);
        Route::post('/{tableId}/add-order', [TableAddOrderController::class, 'addOrder']);
        Route::get('/{tableId}/order-details', [TableAddOrderController::class, 'getOrderDetails']);
        Route::get('/check-status', [TableAddOrderController::class, 'checkTableStatus']);
        Route::get('/status/all', [TableAddOrderController::class, 'getTablesStatus']);
        Route::post('/{tableId}/take-payment', [TableAddOrderController::class, 'takePayment']);
        Route::get('/check-inactive', [TableAddOrderController::class, 'checkInactiveTables']);
        Route::post('/{sourceTableId}/transfer/{targetTableId}', [TableAddOrderController::class, 'transferTable']);
        Route::get('/orders/{orderId}/receipt', [TableAddOrderController::class, 'getOrderReceipt']);
        Route::get('/daily-receipt', [TableAddOrderController::class, 'getDailyReceipt']);
    });

    Route::group(['middleware' => 'auth:sanctum', 'prefix' => 'categories'], function () {
        Route::get('/index', [CategoryController::class, 'index']);
        Route::get('/show/{id}', [CategoryController::class, 'show']);
        Route::post('/store', [CategoryController::class, 'store']);
        Route::delete('/destroy/{id}', [CategoryController::class, 'destroy']);
        Route::post('/update/{id}', [CategoryController::class, 'update']);
    });

    Route::group(['middleware' => 'auth:sanctum', 'prefix' => 'products'], function () {
        Route::get('/index', [ProductController::class, 'index']);
        Route::get('/show/{id}', [ProductController::class, 'show']);
        Route::post('/store', [ProductController::class, 'store']);
        Route::delete('/destroy/{id}', [ProductController::class, 'destroy']);
        Route::post('/update/{id}', [ProductController::class, 'update']);
    });


    Route::group(['middleware' => ['auth:sanctum', AdminMiddleware::class], 'prefix' => 'reports'], function () {
        Route::get('/statistics', [ReportsController::class, 'getStatistics']);
        Route::get('/sales', [ReportsController::class, 'getSalesReport']);
    });


    // Mutfak siparişleri için route
    Route::prefix('kitchen')->group(function () {
        Route::get('/index', [KitchenController::class, 'index']);
        Route::post('/complete/{id}/status', [KitchenController::class, 'updateStatus']);
    });

    // Menu için public route'ları düzenleyelim (middleware kaldırılıyor)
    Route::group(['prefix' => 'menu'], function () {
        Route::get('/categories', [CategoryController::class, 'index']);
        Route::get('/products', [ProductController::class, 'index']);
        Route::get('/tables/active', [TableController::class, 'getActiveTables']);
        Route::post('/tables/{tableId}/add-order', [QrMenuController::class, 'addOrder']);
    });

    Route::group(['middleware' => 'auth:sanctum'], function () {
        Route::get('/qr-orders/pending', [QrOrderController::class, 'getPendingOrders']);
        Route::post('/qr-orders/{id}/approve', [QrOrderController::class, 'approveOrder']);
        Route::post('/qr-orders/{id}/reject', [QrOrderController::class, 'rejectOrder']);
    });

    // Garson route'larını güncelleyelim
    Route::group(['middleware' => ['auth:sanctum', 'waiter'], 'prefix' => 'waiter'], function () {
        Route::get('/tables/active', [TableController::class, 'getActiveTables']);
        Route::post('/waiter-call', [WaiterCallController::class, 'store']);
        Route::get('/waiter-calls/pending', [WaiterCallController::class, 'getPendingCalls']);
        Route::post('/waiter-calls/{id}/complete', [WaiterCallController::class, 'complete']);

        // Mutfak route'ları
        Route::prefix('kitchen')->group(function () {
            Route::get('/index', [KitchenController::class, 'index']);
            Route::post('/complete/{id}/status', [KitchenController::class, 'updateStatus']);
        });
    });


    Route::group(['prefix' => 'payments'], function () {
        Route::get('/index', [PaymentController::class, 'index']);
    });

    // Ortak auth route'ları
    Route::group(['middleware' => 'auth:sanctum'], function () {
        // QR Order route'ları
        Route::get('/qr-orders/pending', [QrOrderController::class, 'getPendingOrders']);
        Route::post('/qr-orders/{id}/approve', [QrOrderController::class, 'approveOrder']);
        Route::post('/qr-orders/{id}/reject', [QrOrderController::class, 'rejectOrder']);

        // Logout işlemi
        Route::post('/logout', [AuthController::class, 'logout']);
    });

    // Admin route grubu içine ekleyin
    Route::group(['middleware' => ['auth:sanctum', AdminMiddleware::class], 'prefix' => 'staff'], function () {
        Route::post('/store', [AuthController::class, 'createStaff']);
        Route::get('/list', [AuthController::class, 'list']);
    });

    Route::post('/admin/staff/destroy/{id}', [AuthController::class, 'destroy']);
});
