<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Logo</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <link href="https://fonts.googleapis.com/css2?family=Plus+Jakarta+Sans:wght@400;500;600;700&display=swap" rel="stylesheet">
    <style>
        body {
            font-family: 'Plus Jakarta Sans', sans-serif;
            background-color: #0A0A0A;
            color: #fff;
            background-image:
                radial-gradient(circle at 100% 0%, rgba(255, 99, 71, 0.08) 0%, transparent 25%),
                radial-gradient(circle at 0% 100%, rgba(255, 165, 0, 0.08) 0%, transparent 25%);
        }
        .menu-card {
            background: rgba(255, 255, 255, 0.03);
            backdrop-filter: blur(12px);
            border: 1px solid rgba(255, 255, 255, 0.05);
        }
        .animate-fade {
            animation: fadeIn 0.6s cubic-bezier(0.2, 0.8, 0.2, 1);
        }
        @keyframes fadeIn {
            0% { opacity: 0; transform: translateY(15px); }
            100% { opacity: 1; transform: translateY(0); }
        }
        .hover-lift {
            transition: all 0.5s cubic-bezier(0.2, 0.8, 0.2, 1);
        }
        .hover-lift:hover {
            transform: translateY(-6px);
            box-shadow: 0 20px 40px rgba(0, 0, 0, 0.3);
        }
        .gradient-text {
            background: linear-gradient(135deg, #FF6B6B, #FFE66D);
            -webkit-background-clip: text;
            -webkit-text-fill-color: transparent;
        }
        .glass-effect {
            background: linear-gradient(135deg, rgba(255, 255, 255, 0.05), rgba(255, 255, 255, 0.02));
            backdrop-filter: blur(10px);
            box-shadow: 0 8px 32px 0 rgba(0, 0, 0, 0.2);
        }
        .custom-scrollbar::-webkit-scrollbar {
            width: 4px;
            height: 4px;
        }
        .custom-scrollbar::-webkit-scrollbar-thumb {
            background: rgba(255, 255, 255, 0.2);
            border-radius: 2px;
        }
        .animate-fade-up {
            animation: fadeUp 0.3s ease-out;
        }
        @keyframes fadeUp {
            from {
                opacity: 0;
                transform: translateY(20px);
            }
            to {
                opacity: 1;
                transform: translateY(0);
            }
        }
    </style>
    <script>
        function loadTables() {
            fetch('/api/v1/tables/active')
                .then(response => response.json())
                .then(data => {
                    if (data.status && data.tables) {
                        const select = document.getElementById('tableSelect');
                        select.innerHTML = '<option value="">Masa Seçin</option>';
                        data.tables.forEach(table => {
                            select.innerHTML += `<option value="${table.id}">${table.name}</option>`;
                        });
                    } else {
                        const select = document.getElementById('tableSelect');
                        select.innerHTML = '<option value="">Masa bulunamadı</option>';
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                    const select = document.getElementById('tableSelect');
                    select.innerHTML = '<option value="">Masa yüklenemedi</option>';
                });
        }

        function showSuccessModal() {
            document.getElementById('waiterModal').classList.add('hidden');
            document.getElementById('successModal').classList.remove('hidden');
        }

        function closeSuccessModal() {
            document.getElementById('successModal').classList.add('hidden');
        }

        function callWaiter(tableId) {
            if (!tableId) {
                alert('Lütfen bir masa seçin');
                return;
            }

            fetch('/api/v1/waiter-call', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({ table_id: tableId })
            })
            .then(response => response.json())
            .then(data => {
                showSuccessModal();
            })
            .catch(error => {
                alert('Bir hata oluştu');
            });
        }

        // Sayfa yüklendiğinde masaları yükle
        document.addEventListener('DOMContentLoaded', loadTables);
    </script>
</head>
<body class="min-h-screen antialiased custom-scrollbar">
    <div class="fixed inset-0 -z-10">
        <div class="absolute inset-0 bg-[#0A0A0A]"></div>
        <div class="absolute inset-0 bg-gradient-to-tr from-rose-500/10 via-transparent to-orange-500/10"></div>
    </div>

    <header class="fixed w-full top-0 z-50">
        <div class="glass-effect backdrop-blur-xl border-b border-white/5">
            <div class="max-w-7xl mx-auto px-6 h-20 flex items-center justify-between">
                <a href="<?php echo e(route('menu.categories')); ?>"
                   class="text-2xl font-bold tracking-tight gradient-text">
                    Logo
                </a>

                <a href="<?php echo e(route('menu.order')); ?>"
                   class="bg-gradient-to-r from-rose-500 to-orange-500 text-white px-6 py-2.5 rounded-xl text-sm font-semibold shadow-lg hover:shadow-xl transform hover:scale-105 transition-all duration-300 flex items-center space-x-2">
                    <svg class="w-5 h-5" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                        <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M3 3h2l.4 2M7 13h10l4-8H5.4M7 13L5.4 5M7 13l-2.293 2.293c-.63.63-.184 1.707.707 1.707H17m0 0a2 2 0 100 4 2 2 0 000-4zm-8 2a2 2 0 11-4 0 2 2 0 014 0z" />
                    </svg>
                    <span>Sipariş Ver</span>
                </a>
            </div>
        </div>
    </header>

    <main class="pt-32 pb-20 px-6 max-w-7xl mx-auto">
        <?php echo $__env->yieldContent('content'); ?>
    </main>

    <footer class="py-8 border-t border-white/5">
        <div class="max-w-7xl mx-auto px-6 text-center">
            <p class="text-sm text-white/40">© <?php echo e(date('Y')); ?> <?php echo e(config('app.name')); ?></p>
        </div>
    </footer>

    <div class="fixed bottom-6 right-6 z-50">
        <button onclick="document.getElementById('waiterModal').classList.remove('hidden')"
                class="bg-gradient-to-r from-rose-500 to-orange-500 text-white px-6 py-3 rounded-full text-sm font-semibold shadow-lg hover:shadow-xl transform hover:scale-105 transition-all duration-300 flex items-center space-x-2">
            <svg class="w-5 h-5" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M15 17h5l-1.405-1.405A2.032 2.032 0 0118 14.158V11a6.002 6.002 0 00-4-5.659V5a2 2 0 10-4 0v.341C7.67 6.165 6 8.388 6 11v3.159c0 .538-.214 1.055-.595 1.436L4 17h5m6 0v1a3 3 0 11-6 0v-1m6 0H9" />
            </svg>
            <span>Garson Çağır</span>
        </button>
    </div>

    <!-- Garson Çağırma Modal -->
    <div id="waiterModal" class="fixed inset-0 z-50 hidden">
        <div class="absolute inset-0 bg-black/50 backdrop-blur-sm"></div>
        <div class="absolute inset-0 flex items-center justify-center p-4">
            <div class="bg-[#1A1A1A] rounded-2xl p-6 w-full max-w-sm border border-white/10">
                <h3 class="text-xl font-bold text-white mb-4">Masa Seçin</h3>
                <select id="tableSelect"
                        class="w-full bg-white/5 border border-white/10 rounded-xl px-4 py-3 text-white mb-4 focus:outline-none focus:border-rose-500">
                    <option value="">Yükleniyor...</option>
                </select>
                <div class="flex space-x-3">
                    <button onclick="document.getElementById('waiterModal').classList.add('hidden')"
                            class="flex-1 px-4 py-3 rounded-xl border border-white/10 text-white/70 hover:text-white transition-colors">
                        İptal
                    </button>
                    <button onclick="callWaiter(document.getElementById('tableSelect').value)"
                            class="flex-1 px-4 py-3 rounded-xl bg-gradient-to-r from-rose-500 to-orange-500 text-white font-semibold hover:shadow-lg transition-shadow">
                        Garson Çağır
                    </button>
                </div>
            </div>
        </div>
    </div>

    <!-- Başarılı Modal -->
    <div id="successModal" class="fixed inset-0 z-50 hidden">
        <div class="absolute inset-0 bg-black/50 backdrop-blur-sm"></div>
        <div class="absolute inset-0 flex items-center justify-center p-4">
            <div class="bg-[#1A1A1A] rounded-2xl p-6 w-full max-w-sm border border-white/10 animate-fade-up">
                <div class="text-center space-y-4">
                    <!-- Başarılı ikonu -->
                    <div class="w-16 h-16 rounded-full bg-gradient-to-r from-rose-500 to-orange-500 mx-auto flex items-center justify-center">
                        <svg class="w-8 h-8 text-white" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                            <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M5 13l4 4L19 7" />
                        </svg>
                    </div>

                    <h3 class="text-xl font-bold text-white">Garson Çağrınız Alındı</h3>
                    <p class="text-white/70 text-sm">Garsonumuz en kısa sürede masanıza gelecektir.</p>

                    <button onclick="closeSuccessModal()"
                            class="w-full px-4 py-3 rounded-xl bg-gradient-to-r from-rose-500 to-orange-500 text-white font-semibold hover:shadow-lg transition-shadow">
                        Tamam
                    </button>
                </div>
            </div>
        </div>
    </div>
</body>
</html>
<?php /**PATH /Applications/MAMP/htdocs/adisyon-back/resources/views/menu/layout.blade.php ENDPATH**/ ?>