'use client'

import { useState, useEffect } from 'react'
import { FiCoffee, FiUser, FiLock, FiPieChart, FiClock, FiGrid } from 'react-icons/fi'
import { authService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'
import { useRouter } from 'next/navigation'
import Modal from '@/components/ui/Modal'

export default function LoginPage() {
  const [email, setEmail] = useState('')
  const [password, setPassword] = useState('')
  const [error, setError] = useState<string | null>(null)
  const [success, setSuccess] = useState<string | null>(null)
  const { login, user } = useUser()
  const router = useRouter()

  useEffect(() => {
    if (user) {
      router.push('/dashboard')
    }
  }, [user, router])

  useEffect(() => {
    let redirectTimer: NodeJS.Timeout
    if (success) {
      redirectTimer = setTimeout(() => {
        router.push('/dashboard')
      }, 3000)
    }
    return () => {
      if (redirectTimer) {
        clearTimeout(redirectTimer)
      }
    }
  }, [success, router])

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault()
    authService.login(email, password)
      .then(response => {
        console.log(response)
        login({
          name: response.data.user.name,
          email: response.data.user.email,
          token: response.data.access_token,
          role: response.data.user.role
        })
      })
      .catch(error => {
        setError('E-posta adresi veya şifre hatalı. Lütfen bilgilerinizi kontrol edip tekrar deneyiniz.')
      })
  }

  return (
    <>
      <div className="min-h-screen flex flex-col lg:flex-row bg-gradient-to-br from-fuchsia-50 via-pink-50 to-purple-50">
        {/* Sol taraf - Branding Alanı */}
        <div className="lg:hidden flex items-center justify-between p-6 bg-white/70 backdrop-blur-lg border-b border-fuchsia-100">
          <div className="flex items-center space-x-3">
            <div className="bg-gradient-to-br from-fuchsia-500 to-purple-500 p-2 rounded-xl shadow-lg">
              <FiCoffee className="w-6 h-6 text-white" />
            </div>
            <span className="text-xl font-bold bg-clip-text text-transparent bg-gradient-to-r from-fuchsia-500 to-purple-500">
              CafePos
            </span>
          </div>
        </div>

        <div className="hidden lg:block lg:w-1/2 relative overflow-hidden">
          <div className="absolute inset-0">
            <div className="absolute inset-0 bg-gradient-to-r from-fuchsia-400/10 to-purple-400/10 backdrop-blur-[1px]" />
            <div className="absolute inset-0" style={{
              backgroundImage: 'url("data:image/svg+xml,%3Csvg width="100" height="100" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg"%3E%3Cpath d="M11 18c3.866 0 7-3.134 7-7s-3.134-7-7-7-7 3.134-7 7 3.134 7 7 7zm48 25c3.866 0 7-3.134 7-7s-3.134-7-7-7-7 3.134-7 7 3.134 7 7 7zm-43-7c1.657 0 3-1.343 3-3s-1.343-3-3-3-3 1.343-3 3 1.343 3 3 3zm63 31c1.657 0 3-1.343 3-3s-1.343-3-3-3-3 1.343-3 3 1.343 3 3 3zM34 90c1.657 0 3-1.343 3-3s-1.343-3-3-3-3 1.343-3 3 1.343 3 3 3zm56-76c1.657 0 3-1.343 3-3s-1.343-3-3-3-3 1.343-3 3 1.343 3 3 3zM12 86c2.21 0 4-1.79 4-4s-1.79-4-4-4-4 1.79-4 4 1.79 4 4 4zm28-65c2.21 0 4-1.79 4-4s-1.79-4-4-4-4 1.79-4 4 1.79 4 4 4zm23-11c2.76 0 5-2.24 5-5s-2.24-5-5-5-5 2.24-5 5 2.24 5 5 5zm-6 60c2.21 0 4-1.79 4-4s-1.79-4-4-4-4 1.79-4 4 1.79 4 4 4zm29 22c2.76 0 5-2.24 5-5s-2.24-5-5-5-5 2.24-5 5 2.24 5 5 5zM32 63c2.76 0 5-2.24 5-5s-2.24-5-5-5-5 2.24-5 5 2.24 5 5 5zm57-13c2.76 0 5-2.24 5-5s-2.24-5-5-5-5 2.24-5 5 2.24 5 5 5zm-9-21c1.105 0 2-.895 2-2s-.895-2-2-2-2 .895-2 2 .895 2 2 2zM60 91c1.105 0 2-.895 2-2s-.895-2-2-2-2 .895-2 2 .895 2 2 2zM35 41c1.105 0 2-.895 2-2s-.895-2-2-2-2 .895-2 2 .895 2 2 2zM12 60c1.105 0 2-.895 2-2s-.895-2-2-2-2 .895-2 2 .895 2 2 2z" fill="%23c026d3" fill-opacity="0.05" fill-rule="evenodd"/%3E%3C/svg%3E")',
            }} />
          </div>
          <div className="relative h-full flex flex-col justify-between p-12">
            <div className="flex items-center">
              <div className="flex items-center space-x-3">
                <div className="bg-gradient-to-br from-fuchsia-500 to-purple-500 p-2 rounded-xl shadow-lg">
                  <FiCoffee className="w-8 h-8 text-white" />
                </div>
                <span className="text-2xl font-bold bg-clip-text text-transparent bg-gradient-to-r from-fuchsia-500 to-purple-500">
                  CafePos
                </span>
              </div>
            </div>

            {/* Orta Kısım */}
            <div className="py-12">
              <h1 className="text-5xl font-bold mb-6 text-slate-800 leading-tight">
                Modern Cafe<br />Yönetim Sistemi
              </h1>
              <p className="text-xl text-slate-600 mb-12 leading-relaxed">
                Cafe işletmenizi dijitalleştirin,<br />verimliliğinizi artırın.
              </p>

              {/* Özellik Kartları */}
              <div className="grid grid-cols-2 gap-6">
                <div className="bg-white/60 backdrop-blur-lg p-6 rounded-2xl shadow-lg border border-fuchsia-100 hover:scale-105 transition-all duration-300 hover:bg-white/80">
                  <div className="bg-gradient-to-br from-fuchsia-400 to-fuchsia-500 w-12 h-12 rounded-xl flex items-center justify-center mb-4 shadow-lg">
                    <FiPieChart className="w-6 h-6 text-white" />
                  </div>
                  <h3 className="font-semibold text-slate-800 mb-1">Anlık Takip</h3>
                  <p className="text-slate-600 text-sm">Siparişlerinizi anlık izleyin</p>
                </div>

                <div className="bg-white/60 backdrop-blur-lg p-6 rounded-2xl shadow-lg border border-purple-100 hover:scale-105 transition-all duration-300 hover:bg-white/80">
                  <div className="bg-gradient-to-br from-purple-400 to-purple-500 w-12 h-12 rounded-xl flex items-center justify-center mb-4 shadow-lg">
                    <FiGrid className="w-6 h-6 text-white" />
                  </div>
                  <h3 className="font-semibold text-slate-800 mb-1">Masa Yönetimi</h3>
                  <p className="text-slate-600 text-sm">Kolay masa organizasyonu</p>
                </div>

                <div className="bg-white/60 backdrop-blur-lg p-6 rounded-2xl shadow-lg border border-pink-100 hover:scale-105 transition-all duration-300 hover:bg-white/80">
                  <div className="bg-gradient-to-br from-pink-400 to-pink-500 w-12 h-12 rounded-xl flex items-center justify-center mb-4 shadow-lg">
                    <FiClock className="w-6 h-6 text-white" />
                  </div>
                  <h3 className="font-semibold text-slate-800 mb-1">Hızlı İşlem</h3>
                  <p className="text-slate-600 text-sm">Zaman kazandıran arayüz</p>
                </div>

                <div className="bg-white/60 backdrop-blur-lg p-6 rounded-2xl shadow-lg border border-fuchsia-100 hover:scale-105 transition-all duration-300 hover:bg-white/80">
                  <div className="bg-gradient-to-br from-fuchsia-500 to-purple-500 w-12 h-12 rounded-xl flex items-center justify-center mb-4 shadow-lg">
                    <svg className="w-6 h-6 text-white" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                      <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M9 5H7a2 2 0 00-2 2v12a2 2 0 002 2h10a2 2 0 002-2V7a2 2 0 00-2-2h-2M9 5a2 2 0 002 2h2a2 2 0 002-2M9 5a2 2 0 012-2h2a2 2 0 012 2" />
                    </svg>
                  </div>
                  <h3 className="font-semibold text-slate-800 mb-1">Raporlama</h3>
                  <p className="text-slate-600 text-sm">Detaylı analiz ve raporlar</p>
                </div>
              </div>
            </div>

            {/* Alt Kısım */}
            <div className="bg-gradient-to-r from-fuchsia-100/50 to-purple-100/50 rounded-2xl p-6 backdrop-blur-xl border border-fuchsia-100/50">
              <p className="text-slate-600 font-medium">
                "İşletmenizi dijital dünyaya taşıyın, verimliliğinizi artırın."
              </p>
            </div>
          </div>
        </div>

        {/* Sağ taraf - Login Formu */}
        <div className="w-full lg:w-1/2 flex flex-col justify-center p-6 sm:p-8 lg:p-12 bg-gradient-to-br from-fuchsia-500/[0.03] via-pink-500/[0.03] to-purple-500/[0.03]">
          <div className="w-full max-w-md mx-auto space-y-8">
            {/* Mobil için mini hero section */}
            <div className="lg:hidden text-center mb-8">
              <h1 className="text-3xl sm:text-4xl font-bold mb-4 text-slate-800 leading-tight">
                Modern Cafe<br />Yönetim Sistemi
              </h1>
              <p className="text-lg text-slate-600">
                Cafe işletmenizi dijitalleştirin
              </p>
            </div>

            <div className="bg-white/80 backdrop-blur-xl p-8 rounded-3xl shadow-[0_8px_30px_rgb(0,0,0,0.04)] border border-white/40">
              <div className="text-center mb-8">
                <h2 className="text-2xl sm:text-3xl font-bold bg-clip-text text-transparent bg-gradient-to-r from-fuchsia-600 to-purple-600">
                  Hoş Geldiniz
                </h2>
                <p className="mt-2 text-slate-600">
                  Hesabınıza giriş yapın
                </p>
              </div>

              <form className="mt-8 space-y-6" onSubmit={handleSubmit}>
                <div className="space-y-5">
                  <div className="relative group">
                    <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                      <FiUser className="h-5 w-5 text-fuchsia-400 group-focus-within:text-fuchsia-500 transition-colors" />
                    </div>
                    <input
                      id="email"
                      name="email"
                      type="email"
                      required
                      value={email}
                      onChange={(e) => setEmail(e.target.value)}
                      className="block w-full pl-10 px-4 py-3.5 bg-white/60 border border-slate-200 rounded-2xl text-slate-800 placeholder-slate-400 focus:outline-none focus:ring-2 focus:ring-fuchsia-400/50 focus:border-transparent transition-all duration-200 shadow-sm hover:bg-white/80"
                      placeholder="E-posta adresiniz"
                    />
                  </div>

                  <div className="relative group">
                    <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                      <FiLock className="h-5 w-5 text-fuchsia-400 group-focus-within:text-fuchsia-500 transition-colors" />
                    </div>
                    <input
                      id="password"
                      name="password"
                      type="password"
                      required
                      value={password}
                      onChange={(e) => setPassword(e.target.value)}
                      className="block w-full pl-10 px-4 py-3.5 bg-white/60 border border-slate-200 rounded-2xl text-slate-800 placeholder-slate-400 focus:outline-none focus:ring-2 focus:ring-fuchsia-400/50 focus:border-transparent transition-all duration-200 shadow-sm hover:bg-white/80"
                      placeholder="Şifreniz"
                    />
                  </div>
                </div>

                <div className="flex flex-col sm:flex-row items-start sm:items-center justify-between space-y-3 sm:space-y-0">
                  <div className="flex items-center">
                    <input
                      id="remember-me"
                      name="remember-me"
                      type="checkbox"
                      className="h-4 w-4 text-fuchsia-500 border-slate-300 rounded focus:ring-fuchsia-400/50"
                    />
                    <label htmlFor="remember-me" className="ml-2 block text-sm text-slate-600">
                      Beni Hatırla
                    </label>
                  </div>

                  <div className="text-sm w-full sm:w-auto text-right">
                    <a href="#" className="font-medium text-fuchsia-500 hover:text-fuchsia-600 transition-colors">
                      Şifremi Unuttum
                    </a>
                  </div>
                </div>

                <button
                  type="submit"
                  className="group relative w-full flex justify-center py-3.5 px-4 border border-transparent rounded-2xl text-white bg-gradient-to-r from-fuchsia-500 to-purple-500 hover:from-fuchsia-600 hover:to-purple-600 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-fuchsia-400/50 transition-all duration-200 text-sm font-semibold shadow-lg hover:shadow-xl hover:scale-[1.01] active:scale-[0.99]"
                >
                  Giriş Yap
                </button>
              </form>
            </div>

            {/* Mobil için özellik kartları */}
            <div className="lg:hidden grid grid-cols-1 sm:grid-cols-2 gap-4 mt-8">
              <div className="bg-white/60 backdrop-blur-lg p-4 rounded-xl shadow-lg border border-fuchsia-100">
                <div className="flex items-center space-x-3">
                  <div className="bg-gradient-to-br from-fuchsia-400 to-fuchsia-500 w-10 h-10 rounded-lg flex items-center justify-center shadow-lg">
                    <FiPieChart className="w-5 h-5 text-white" />
                  </div>
                  <div>
                    <h3 className="font-semibold text-slate-800">Anlık Takip</h3>
                    <p className="text-sm text-slate-600">Siparişlerinizi anlık izleyin</p>
                  </div>
                </div>
              </div>

              <div className="bg-white/60 backdrop-blur-lg p-4 rounded-xl shadow-lg border border-purple-100">
                <div className="flex items-center space-x-3">
                  <div className="bg-gradient-to-br from-purple-400 to-purple-500 w-10 h-10 rounded-lg flex items-center justify-center shadow-lg">
                    <FiGrid className="w-5 h-5 text-white" />
                  </div>
                  <div>
                    <h3 className="font-semibold text-slate-800">Masa Yönetimi</h3>
                    <p className="text-sm text-slate-600">Kolay organizasyon</p>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>

      {/* Hata Modalı */}
      <Modal
        isOpen={!!error}
        onClose={() => setError(null)}
        title="Giriş Başarısız"
        message={error || ''}
      />

      {/* Başarı Modalı */}
      <Modal
        isOpen={!!success}
        onClose={() => setSuccess(null)}
        title="Giriş Başarılı"
        message={success || ''}
      />

    </>
  )
} 