export type TableStatus = 'active' | 'empty' | 'reserved' | 'waiting'

interface StatusConfig {
  color: string
  text: string
}

export const TABLE_STATUS_CONFIG: Record<TableStatus, StatusConfig> = {
  active: {
    color: 'bg-emerald-100/50 dark:bg-emerald-900/50 text-emerald-600 dark:text-emerald-400',
    text: 'Dolu'
  },
  empty: {
    color: 'bg-slate-100/50 dark:bg-slate-800/50 text-slate-600 dark:text-slate-400',
    text: 'Boş'
  },
  reserved: {
    color: 'bg-amber-100/50 dark:bg-amber-900/50 text-amber-600 dark:text-amber-400',
    text: 'Rezerve'
  },
  waiting: {
    color: 'bg-red-100 dark:bg-red-900/50 text-red-600 dark:text-red-400',
    text: 'Şipariş Alınmalı'
  }
}

export const getStatusColor = (status: string): string => {
  return (TABLE_STATUS_CONFIG[status as TableStatus]?.color || 
          TABLE_STATUS_CONFIG.empty.color)
}

export const getStatusText = (status: string): string => {
  return (TABLE_STATUS_CONFIG[status as TableStatus]?.text || status)
} 

export const getDate = (dateString: string): string => {
  const date = new Date(dateString)
  return date.toLocaleDateString('tr-TR', {
    day: '2-digit',
    month: '2-digit',
    year: 'numeric',
    hour: '2-digit',
    minute: '2-digit'
  })
}