const express = require('express')
const next = require('next')
const compression = require('compression')

const port = process.env.PORT || 3000
const dev = process.env.NODE_ENV !== 'production'
const app = next({ dev })
const handle = app.getRequestHandler()

app.prepare().then(() => {
  const server = express()
  
  // Gzip sıkıştırma
  server.use(compression())
  
  // Security headers
  server.use((req, res, next) => {
    res.setHeader('X-XSS-Protection', '1; mode=block')
    res.setHeader('X-Frame-Options', 'SAMEORIGIN')
    res.setHeader('X-Content-Type-Options', 'nosniff')
    next()
  })

  // API rate limiting
  const rateLimit = require('express-rate-limit')
  server.use('/api/', rateLimit({
    windowMs: 15 * 60 * 1000, // 15 dakika
    max: 100 // IP başına limit
  }))

  // Next.js request handler
  server.all('*', (req, res) => {
    return handle(req, res)
  })

  server.listen(port, (err) => {
    if (err) throw err
    console.log(`> Ready on http://localhost:${port}`)
  })
}) 