import { create } from 'zustand'
import { tableService } from '@/services/api'

interface StatusStore {
  lastCheck: Date | null
  checkInProgress: boolean
  onStatusUpdate: (() => void) | null
  checkStatus: (token: string) => Promise<void>
  setOnStatusUpdate: (callback: (() => void) | null) => void
}

export const useStatusStore = create<StatusStore>((set, get) => ({
  lastCheck: null,
  checkInProgress: false,
  onStatusUpdate: null,

  setOnStatusUpdate: (callback) => {
    set({ onStatusUpdate: callback })
  },

  checkStatus: async (token: string) => {
    if (get().checkInProgress) return

    set({ checkInProgress: true })
    try {
      const response = await tableService.checkInactive(token)
      
      // Status değişikliği varsa
      if (response.data.status_changed) {
        // Status güncellemesinden sonra callback'i çağır
        const onUpdate = get().onStatusUpdate
        if (onUpdate && typeof onUpdate === 'function') {
          onUpdate()
        }
      }
    } catch (error) {
      console.error('Status kontrol hatası:', error)
    } finally {
      set({ checkInProgress: false })
    }
  }
})) 